==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v1/model/SyntheticsCIBatchMetadataCI.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.Objects;

/** Description of the CI provider. */
@JsonPropertyOrder({
  SyntheticsCIBatchMetadataCI.JSON_PROPERTY_PIPELINE,
  SyntheticsCIBatchMetadataCI.JSON_PROPERTY_PROVIDER
})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class SyntheticsCIBatchMetadataCI {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_PIPELINE = "pipeline";
  private SyntheticsCIBatchMetadataPipeline pipeline;

  public static final String JSON_PROPERTY_PROVIDER = "provider";
  private SyntheticsCIBatchMetadataProvider provider;

  public SyntheticsCIBatchMetadataCI pipeline(SyntheticsCIBatchMetadataPipeline pipeline) {
    this.pipeline = pipeline;
    this.unparsed |= pipeline.unparsed;
    return this;
  }

  /**
   * Description of the CI pipeline.
   *
   * @return pipeline
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_PIPELINE)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public SyntheticsCIBatchMetadataPipeline getPipeline() {
    return pipeline;
  }

  public void setPipeline(SyntheticsCIBatchMetadataPipeline pipeline) {
    this.pipeline = pipeline;
  }

  public SyntheticsCIBatchMetadataCI provider(SyntheticsCIBatchMetadataProvider provider) {
    this.provider = provider;
    this.unparsed |= provider.unparsed;
    return this;
  }

  /**
   * Description of the CI provider.
   *
   * @return provider
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_PROVIDER)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public SyntheticsCIBatchMetadataProvider getProvider() {
    return provider;
  }

  public void setProvider(SyntheticsCIBatchMetadataProvider provider) {
    this.provider = provider;
  }

  /** Return true if this SyntheticsCIBatchMetadataCI object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SyntheticsCIBatchMetadataCI syntheticsCiBatchMetadataCi = (SyntheticsCIBatchMetadataCI) o;
    return Objects.equals(this.pipeline, syntheticsCiBatchMetadataCi.pipeline)
        && Objects.equals(this.provider, syntheticsCiBatchMetadataCi.provider);
  }

  @Override
  public int hashCode() {
    return Objects.hash(pipeline, provider);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SyntheticsCIBatchMetadataCI {\n");
    sb.append("    pipeline: ").append(toIndentedString(pipeline)).append("\n");
    sb.append("    provider: ").append(toIndentedString(provider)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> datadog-api-client-2.24.0-sources.jar: com/datadog/api/client/v1/model/SyntheticsCIBatchMetadataCI.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/** Description of the CI provider. */
@JsonPropertyOrder({
  SyntheticsCIBatchMetadataCI.JSON_PROPERTY_PIPELINE,
  SyntheticsCIBatchMetadataCI.JSON_PROPERTY_PROVIDER
})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class SyntheticsCIBatchMetadataCI {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_PIPELINE = "pipeline";
  private SyntheticsCIBatchMetadataPipeline pipeline;

  public static final String JSON_PROPERTY_PROVIDER = "provider";
  private SyntheticsCIBatchMetadataProvider provider;

  public SyntheticsCIBatchMetadataCI pipeline(SyntheticsCIBatchMetadataPipeline pipeline) {
    this.pipeline = pipeline;
    this.unparsed |= pipeline.unparsed;
    return this;
  }

  /**
   * Description of the CI pipeline.
   *
   * @return pipeline
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_PIPELINE)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public SyntheticsCIBatchMetadataPipeline getPipeline() {
    return pipeline;
  }

  public void setPipeline(SyntheticsCIBatchMetadataPipeline pipeline) {
    this.pipeline = pipeline;
  }

  public SyntheticsCIBatchMetadataCI provider(SyntheticsCIBatchMetadataProvider provider) {
    this.provider = provider;
    this.unparsed |= provider.unparsed;
    return this;
  }

  /**
   * Description of the CI provider.
   *
   * @return provider
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_PROVIDER)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public SyntheticsCIBatchMetadataProvider getProvider() {
    return provider;
  }

  public void setProvider(SyntheticsCIBatchMetadataProvider provider) {
    this.provider = provider;
  }

  /**
   * A container for additional, undeclared properties. This is a holder for any undeclared
   * properties as specified with the 'additionalProperties' keyword in the OAS document.
   */
  private Map<String, Object> additionalProperties;

  /**
   * Set the additional (undeclared) property with the specified name and value. If the property
   * does not already exist, create it otherwise replace it.
   *
   * @param key The arbitrary key to set
   * @param value The associated value
   * @return SyntheticsCIBatchMetadataCI
   */
  @JsonAnySetter
  public SyntheticsCIBatchMetadataCI putAdditionalProperty(String key, Object value) {
    if (this.additionalProperties == null) {
      this.additionalProperties = new HashMap<String, Object>();
    }
    this.additionalProperties.put(key, value);
    return this;
  }

  /**
   * Return the additional (undeclared) property.
   *
   * @return The additional properties
   */
  @JsonAnyGetter
  public Map<String, Object> getAdditionalProperties() {
    return additionalProperties;
  }

  /**
   * Return the additional (undeclared) property with the specified name.
   *
   * @param key The arbitrary key to get
   * @return The specific additional property for the given key
   */
  public Object getAdditionalProperty(String key) {
    if (this.additionalProperties == null) {
      return null;
    }
    return this.additionalProperties.get(key);
  }

  /** Return true if this SyntheticsCIBatchMetadataCI object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SyntheticsCIBatchMetadataCI syntheticsCiBatchMetadataCi = (SyntheticsCIBatchMetadataCI) o;
    return Objects.equals(this.pipeline, syntheticsCiBatchMetadataCi.pipeline)
        && Objects.equals(this.provider, syntheticsCiBatchMetadataCi.provider)
        && Objects.equals(
            this.additionalProperties, syntheticsCiBatchMetadataCi.additionalProperties);
  }

  @Override
  public int hashCode() {
    return Objects.hash(pipeline, provider, additionalProperties);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SyntheticsCIBatchMetadataCI {\n");
    sb.append("    pipeline: ").append(toIndentedString(pipeline)).append("\n");
    sb.append("    provider: ").append(toIndentedString(provider)).append("\n");
    sb.append("    additionalProperties: ")
        .append(toIndentedString(additionalProperties))
        .append("\n");
    sb.append('}');
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
